@@ -19,7 +19,11 @@
 #ifdef CAPSTONE_HAS_X86
 
 #include <stdarg.h>   /* for va_*()       */
+#if defined(CAPSTONE_HAS_OSXKERNEL)
+#include <libkern/libkern.h>
+#else
 #include <stdlib.h>   /* for exit()       */
+#endif
 
 #include "../../cs_priv.h"
 #include "../../utils.h"
@@ -401,7 +405,8 @@ static int readPrefixes(struct InternalInstruction *insn)
 						return -1;
 					if ((byte & 0xf0) == 0x40) {
 						// another REX prefix, but we only remember the last one
-						consumeByte(insn, &byte);
+						if (consumeByte(insn, &byte))
+							return -1;
 					} else
 						break;
 				}
@@ -436,8 +441,11 @@ static int readPrefixes(struct InternalInstruction *insn)
 			break;
 
 		if (insn->readerCursor - 1 == insn->startLocation
-				&& (byte == 0xf2 || byte == 0xf3)
-				&& !lookAtByte(insn, &nextByte)) {
+				&& (byte == 0xf2 || byte == 0xf3)) {
+
+			if (lookAtByte(insn, &nextByte))
+				return -1;
+
 			/*
 			 * If the byte is 0xf2 or 0xf3, and any of the following conditions are
 			 * met:
@@ -650,8 +658,10 @@ static int readPrefixes(struct InternalInstruction *insn)
 
 		if (insn->vectorExtensionType == TYPE_VEX_3B) {
 			insn->vectorExtensionPrefix[0] = byte;
-			consumeByte(insn, &insn->vectorExtensionPrefix[1]);
-			consumeByte(insn, &insn->vectorExtensionPrefix[2]);
+			if (consumeByte(insn, &insn->vectorExtensionPrefix[1]))
+				return -1;
+			if (consumeByte(insn, &insn->vectorExtensionPrefix[2]))
+				return -1;
 
 			/* We simulate the REX prefix for simplicity's sake */
 			if (insn->mode == MODE_64BIT) {
@@ -679,7 +689,8 @@ static int readPrefixes(struct InternalInstruction *insn)
 
 		if (insn->vectorExtensionType == TYPE_VEX_2B) {
 			insn->vectorExtensionPrefix[0] = byte;
-			consumeByte(insn, &insn->vectorExtensionPrefix[1]);
+			if (consumeByte(insn, &insn->vectorExtensionPrefix[1]))
+				return -1;
 
 			if (insn->mode == MODE_64BIT) {
 				insn->rexPrefix = 0x40
@@ -711,8 +722,10 @@ static int readPrefixes(struct InternalInstruction *insn)
 
 		if (insn->vectorExtensionType == TYPE_XOP) {
 			insn->vectorExtensionPrefix[0] = byte;
-			consumeByte(insn, &insn->vectorExtensionPrefix[1]);
-			consumeByte(insn, &insn->vectorExtensionPrefix[2]);
+			if (consumeByte(insn, &insn->vectorExtensionPrefix[1]))
+				return -1;
+			if (consumeByte(insn, &insn->vectorExtensionPrefix[2]))
+				return -1;
 
 			/* We simulate the REX prefix for simplicity's sake */
 			if (insn->mode == MODE_64BIT) {
@@ -741,7 +754,8 @@ static int readPrefixes(struct InternalInstruction *insn)
 						return -1;
 					if ((opcodeByte & 0xf0) == 0x40) {
 						// another REX prefix, but we only remember the last one
-						consumeByte(insn, &byte);
+						if (consumeByte(insn, &byte))
+							return -1;
 					} else
 						break;
 				}
@@ -807,7 +821,7 @@ static int readOpcode(struct InternalInstruction *insn)
 	/* Determine the length of the primary opcode */
 	uint8_t current;
 
-	// printf(">>> readOpcode()\n");
+	// printf(">>> readOpcode() = %x\n", insn->readerCursor);
 
 	insn->opcodeType = ONEBYTE;
 
@@ -1122,17 +1136,16 @@ static int getID(struct InternalInstruction *insn)
 			return -1;
 		}
 	} else {
-		if (insn->mode != MODE_16BIT && isPrefixAtLocation(insn, 0x66))
-			attrMask |= ATTR_OPSIZE;
-		else if (isPrefixAtLocation(insn, 0x67))
+		if (insn->mode != MODE_16BIT && isPrefixAtLocation(insn, 0x66)) {
+			if (insn->twoByteEscape != 0x0f)
+				attrMask |= ATTR_OPSIZE;
+		} else if (isPrefixAtLocation(insn, 0x67))
 			attrMask |= ATTR_ADSIZE;
 
 		if (isPrefixAtLocation(insn, 0xf3)) {
-			if (insn->twoByteEscape == 0x0f)	// 0x66, 0x0f, ... like CRC32 case
-				attrMask |= ATTR_XS;
+			attrMask |= ATTR_XS;
 		} else if (isPrefixAtLocation(insn, 0xf2)) {
-			if (insn->twoByteEscape == 0x0f)	// 0x66, 0x0f, ... like CRC32 case
-				attrMask |= ATTR_XD;
+			attrMask |= ATTR_XD;
 		}
 	}
 
@@ -2081,6 +2094,7 @@ static bool checkPrefix(struct InternalInstruction *insn)
 			case X86_BTS64mr:
 
 			// CMPXCHG
+			case X86_CMPXCHG16B:
 			case X86_CMPXCHG16rm:
 			case X86_CMPXCHG32rm:
 			case X86_CMPXCHG64rm:
